@@ -1,7 +1,7 @@
 package IPC::System::Options;
 
 our $DATE = '2015-02-07'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -10,14 +10,33 @@ use warnings;
 use Carp;
 use Proc::ChildError qw(explain_child_error);
 
-use Exporter qw(import);
-our @EXPORT_OK = qw(system backtick);
-
 my $log;
+our %Global_Opts;
+
+sub import {
+    my $self = shift;
+
+    my $caller = caller();
+    my $i = 0;
+    while ($i < @_) {
+        if ($_[$i] eq 'system' || $_[$i] eq 'backtick') {
+            no strict 'refs';
+            *{"$caller\::$_[$i]"} = \&{$_[$i]};
+        } elsif ($_[$i] =~ /\A-(.+)/) {
+            croak "$_[$i] requires an argument" unless $i < @_-1;
+            $Global_Opts{$1} = $_[$i+1];
+            $i++;
+        } else {
+            croak "$_[$i] is not exported by ".__PACKAGE__;
+        }
+        $i++;
+    }
+}
 
 sub _system_or_backtick {
     my $which = shift;
     my $opts = ref($_[0]) eq 'HASH' ? shift : {};
+    $opts->{$_} //= $Global_Opts{$_} for keys %Global_Opts;
 
     local $ENV{LC_ALL}   = $opts->{lang} if $opts->{lang};
     local $ENV{LANGUAGE} = $opts->{lang} if $opts->{lang};
@@ -79,7 +98,7 @@ sub _system_or_backtick {
     } # which
 
     if ($?) {
-        $log->tracef("%s(%s) failed: %d (%s)",
+        $log->errorf("%s(%s) failed: %d (%s)",
                      $which, \@_, $?, explain_child_error())
             if $opts->{log};
         croak "$which(".join(" ", @_).") failed: " . explain_child_error()
@@ -112,15 +131,18 @@ IPC::System::Options - Perl's system() and backtick/qx replacement/wrapper, with
 
 =head1 VERSION
 
-This document describes version 0.04 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-02-07.
+This document describes version 0.05 of IPC::System::Options (from Perl distribution IPC-System-Options), released on 2015-02-07.
 
 =head1 SYNOPSIS
 
- use IPC::System::Options qw(system);
+ use IPC::System::Options qw(system backtick);
 
  # use exactly like system()
  system(...);
 
+ # use exactly like backtick (qx, ``)
+ my $res = backtick(...);
+
  # but it accepts an optional hash first argument to specify options
  system({...}, ...);
 
@@ -134,6 +156,10 @@ This document describes version 0.04 of IPC::System::Options (from Perl distribu
  # log using Log::Any, die on failure
  system({log=>1, die=>1}, "blah", ...);
 
+Set default options for all calls (prefix each option with dash):
+
+ use IPC::System::Options 'system', 'backtick', -log=>1, -die=>1;
+
 =head1 DESCRIPTION
 
 =head1 FUNCTIONS
